@@ -8,8 +8,14 @@ logger = logging.getLogger(__name__)
 
 
 def get_bq_table(bq_client: bigquery.Client, table_name: str) -> bigquery.table.Table:
-    dataset_ref = bq_client.dataset(table_name.split(".")[0])
-    table_ref = dataset_ref.table(table_name.split(".")[1])
+    table_info = table_name.split(".")
+    if len(table_info) > 2:
+        dataset_ref = bq_client.dataset(table_info[1], table_info[0])
+        table_ref = dataset_ref.table(table_info[2])
+    else:
+        dataset_ref = bq_client.dataset(table_info[0])
+        table_ref = dataset_ref.table(table_info[1])
+
     return bq_client.get_table(table_ref)
 
 
