@@ -1,4 +1,6 @@
 import io
+import logging
+
 import avro
 import avro.schema
 import avro.io
@@ -7,6 +9,8 @@ import requests
 
 from datetime import datetime
 
+logger = logging.getLogger(__name__)
+
 
 def get_schema_from_registry(schema_registry, message, schema_cache):
     schema_id = struct.unpack(">L", message.value[1:5])[0]
